@@ -14,6 +14,7 @@
 #include "SKINI.msg"
 #include <iostream>
 #include <stdlib.h>
+#include <stdio.h>
 
 void usage(void) {
   std::cout << "\nuseage: Md2Skini <flag(s)>\n\n";
@@ -211,7 +212,7 @@ int main( int argc,char *argv[] )
   try {
     midiin = new RtMidiIn();
   }
-  catch (RtError &error) {
+  catch (RtMidiError &error) {
     error.printMessage();
     if ( file != NULL ) fclose( file );
     exit(EXIT_FAILURE);
@@ -232,7 +233,7 @@ int main( int argc,char *argv[] )
   try {
     midiin->openPort( port );
   }
-  catch (RtError &error) {
+  catch (RtMidiError &error) {
     error.printMessage();
     goto cleanup;
   }
