@@ -99,7 +99,7 @@ int main(int argc, char *argv[])
   try {
     dac.openStream( &parameters, NULL, format, (unsigned int)Stk::sampleRate(), &bufferFrames, &tick, (void *)&input );
   }
-  catch ( RtError &error ) {
+  catch ( RtAudioError &error ) {
     error.printMessage();
     goto cleanup;
   }
@@ -113,7 +113,7 @@ int main(int argc, char *argv[])
   try {
     dac.startStream();
   }
-  catch ( RtError &error ) {
+  catch ( RtAudioError &error ) {
     error.printMessage();
     goto cleanup;
   }
@@ -127,7 +127,7 @@ int main(int argc, char *argv[])
   try {
     dac.closeStream();
   }
-  catch ( RtError &error ) {
+  catch ( RtAudioError &error ) {
     error.printMessage();
   }
 
