@@ -17,7 +17,7 @@
 /***************************************************/
 
 #include "BlowBotl.h"
-#include "SKINI.msg"
+#include "SKINImsg.h"
 
 namespace stk {
 
