@@ -34,7 +34,7 @@
 /***************************************************/
 
 #include "BlowHole.h"
-#include "SKINI.msg"
+#include "SKINImsg.h"
 #include <cmath>
 
 namespace stk {
