@@ -25,7 +25,7 @@
 /***************************************************/
 
 #include "Bowed.h"
-#include "SKINI.msg"
+#include "SKINImsg.h"
 
 namespace stk {
 
