@@ -24,7 +24,7 @@
 /***************************************************/
 
 #include "FM.h"
-#include "SKINI.msg"
+#include "SKINImsg.h"
 
 namespace stk {
 
