@@ -23,7 +23,7 @@
 /***************************************************/
 
 #include "Flute.h"
-#include "SKINI.msg"
+#include "SKINImsg.h"
 
 namespace stk {
 
