@@ -27,7 +27,7 @@
 /***************************************************/
 
 #include "Mandolin.h"
-#include "SKINI.msg"
+#include "SKINImsg.h"
 
 namespace stk {
 
