@@ -29,7 +29,7 @@
 /***************************************************/
 
 #include "ModalBar.h"
-#include "SKINI.msg"
+#include "SKINImsg.h"
 #include <cmath>
 
 namespace stk {
