@@ -19,7 +19,7 @@
 /***************************************************/
 
 #include "Moog.h"
-#include "SKINI.msg"
+#include "SKINImsg.h"
 
 namespace stk {
 
