@@ -18,7 +18,7 @@
 /***************************************************/
 
 #include "Resonate.h"
-#include "SKINI.msg"
+#include "SKINImsg.h"
 
 namespace stk {
 
