@@ -49,7 +49,7 @@
 /***************************************************/
 
 #include "Shakers.h"
-#include "SKINI.msg"
+#include "SKINImsg.h"
 
 namespace stk {
 
