@@ -22,7 +22,7 @@
 /***************************************************/
 
 #include "StifKarp.h"
-#include "SKINI.msg"
+#include "SKINImsg.h"
 #include <cmath>
 
 namespace stk {
